Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(940)

Unified Diff: chrome/browser/ui/cocoa/browser_window_touch_bar.h

Issue 2860163004: [Mac] Fix for Tab Fullscreen Touch Bar (Closed)
Patch Set: Fix for avi Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ui/cocoa/browser_window_touch_bar.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/cocoa/browser_window_touch_bar.h
diff --git a/chrome/browser/ui/cocoa/browser_window_touch_bar.h b/chrome/browser/ui/cocoa/browser_window_touch_bar.h
index a65c54784e92f513eb6a50d7601b0134021efc40..99cc36c898bcd08f1da02f2ba52af3458fce9b17 100644
--- a/chrome/browser/ui/cocoa/browser_window_touch_bar.h
+++ b/chrome/browser/ui/cocoa/browser_window_touch_bar.h
@@ -22,8 +22,9 @@ class Browser;
// True if the current page is starred. Used by star touch bar button.
@property(nonatomic, assign) BOOL isStarred;
-// Returns a touch bar item identifier for the given |id|.
-+ (NSString*)touchBarIdForItemId:(NSString*)id;
+// Returns a touch bar item identifier for the given |touchBarId| and |itemId|.
++ (NSString*)identifierForTouchBarId:(NSString*)touchBarId
+ itemId:(NSString*)itemId;
// Designated initializer.
- (instancetype)initWithBrowser:(Browser*)browser
« no previous file with comments | « no previous file | chrome/browser/ui/cocoa/browser_window_touch_bar.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698